@@ -12,8 +12,12 @@ from swh.model.hashutil import DEFAULT_ALGORITHMS
 from swh.model.model import (
     Content,
     Directory,
+    MetadataAuthority,
+    MetadataFetcher,
     Origin,
     OriginVisit,
+    OriginVisitStatus,
+    RawExtrinsicMetadata,
     Release,
     Revision,
     SkippedContent,
@@ -21,7 +25,18 @@ from swh.model.model import (
 )
 
 ModelObject = Union[
-    Content, Directory, Origin, OriginVisit, Release, Revision, SkippedContent, Snapshot
+    Content,
+    Directory,
+    MetadataAuthority,
+    MetadataFetcher,
+    Origin,
+    OriginVisit,
+    OriginVisitStatus,
+    RawExtrinsicMetadata,
+    Release,
+    Revision,
+    SkippedContent,
+    Snapshot,
 ]
 
 KeyType = Union[Dict[str, str], Dict[str, bytes], bytes]
@@ -44,7 +59,16 @@ def object_key(
 
 
 @overload
-def object_key(object_type: str, object_: OriginVisit) -> Dict[str, str]:
+def object_key(
+    object_type: str,
+    object_: Union[
+        MetadataAuthority,
+        MetadataFetcher,
+        OriginVisit,
+        OriginVisitStatus,
+        RawExtrinsicMetadata,
+    ],
+) -> Dict[str, str]:
     ...
 
 
@@ -68,6 +92,26 @@ def object_key(object_type: str, object_) -> KeyType:
             "visit": str(object_.visit),
             "date": str(object_.date),
         }
+    elif object_type == "metadata_authority":
+        return {
+            "type": object_.type.value,
+            "url": object_.url,
+        }
+    elif object_type == "metadata_fetcher":
+        return {
+            "name": object_.name,
+            "version": object_.version,
+        }
+    elif object_type == "raw_extrinsic_metadata":
+        return {
+            "type": object_.type.value,
+            "id": str(object_.id),
+            "authority_type": object_.authority.type.value,
+            "authority_url": object_.authority.url,
+            "discovery_date": str(object_.discovery_date),
+            "fetcher_name": object_.fetcher.name,
+            "fetcher_version": object_.fetcher.version,
+        }
     else:
         raise ValueError("Unknown object type: %s." % object_type)
 
